@@ -33,9 +33,12 @@ fi
 
 cat "$service_certificate" "$ca_path" "$service_key" > "$service_pem"
 
-haproxy_container_name=$($container_cli ps --format="{{.Names}}" | grep haproxy)
+haproxy_container_name=$($container_cli ps --format="{{.Names}}" | grep -w -E 'haproxy(-bundle-.*-[0-9]+)?')
 
 if [ "$ACTION" == "reload" ]; then
+    # Refresh the cert at the mount-point
+    $container_cli cp $service_pem "$haproxy_container_name:/var/lib/kolla/config_files/src-tls/$service_pem"
+
     # Copy the new cert from the mount-point to the real path
     $container_cli exec "$haproxy_container_name" cp "/var/lib/kolla/config_files/src-tls$service_pem" "$service_pem"
 
@@ -43,7 +46,7 @@ if [ "$ACTION" == "reload" ]; then
     $container_cli exec "$haproxy_container_name" chown haproxy:haproxy "$service_pem"
 
     # Trigger a reload for HAProxy to read the new certificates
-    pkill -f -HUP haproxy-systemd-wrapper
+    $container_cli kill --signal HUP "$haproxy_container_name"
 elif [ "$ACTION" == "restart" ]; then
     # Copying the certificate and permissions will be handled by kolla's start
     # script.
